@@ -11,10 +11,9 @@ register = template.Library()
 @register.assignment_tag
 def get_category(entry=None):
     if entry:
-        try:
-            return EntryCategory.objects.get(entry=entry).category
-        except EntryCategory.DoesNotExist:
-            pass
+        return [
+            entrycat.category for entrycat in EntryCategory.objects.filter(
+                entry=entry)]
     return None
 
 
